@@ -1,3 +1,6 @@
+"""
+Very small module with one test: test_write_to_fil()
+"""
 import blimpy as bl
 
 from tests.data import voyager_h5
@@ -9,4 +12,4 @@ def test_write_to_fil():
     a.write_to_fil('test_out.fil')
 
 if __name__ == "__main__":
-    test_write_to_fil()
\ No newline at end of file
+    test_write_to_fil()
